| bootstrap_survival | R Documentation |
Draws bs_samples bootstrap resamples (with replacement) of the
per-observation survival curves stored in gg_dta, computes the column
means to obtain a bootstrapped mean curve per resample, then returns the
pointwise quantiles at level_set and the overall mean across
resamples.
bootstrap_survival(gg_dta, bs_samples, level_set)
gg_dta |
A wide |
bs_samples |
Integer; number of bootstrap resamples. |
level_set |
Numeric vector of length 2 giving the lower and upper
quantile probabilities for the confidence band (e.g. |
A data.frame with one row per unique event time and columns
value (time), lower, upper, median, and
mean.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.