| calc_roc.rfsrc | R Documentation |
Receiver Operator Characteristic calculator
## S3 method for class 'rfsrc'
calc_roc(object, dta, which_outcome = "all", oob = TRUE, ...)
object |
A fitted |
dta |
A factor (or coercible to factor) of the true observed class
labels, one per observation. Typically |
which_outcome |
Integer index of the class for which the ROC curve is
computed (e.g. |
oob |
Logical; if |
... |
Extra arguments passed to helper functions (currently unused). |
For a randomForestSRC prediction and the actual response value, calculate the specificity (1-False Positive Rate) and sensitivity (True Positive Rate) of a predictor.
This is a helper function for the gg_roc functions, and
not intended for use by the end user.
A gg_roc data.frame with columns sens
(sensitivity), spec (specificity), and pct (the probability
threshold), with one row per unique prediction value. Suitable for passing
to calc_auc or plot.gg_roc.
calc_auc gg_roc
plot.gg_roc
## Taken from the gg_roc example
rfsrc_iris <- rfsrc(Species ~ ., data = iris)
gg_dta <- calc_roc(rfsrc_iris, rfsrc_iris$yvar,
which_outcome = 1, oob = TRUE
)
gg_dta <- calc_roc(rfsrc_iris, rfsrc_iris$yvar,
which_outcome = 1, oob = FALSE
)
rf_iris <- randomForest(Species ~ ., data = iris)
gg_dta <- calc_roc(rf_iris, rf_iris$yvar,
which_outcome = 1
)
gg_dta <- calc_roc(rf_iris, rf_iris$yvar,
which_outcome = 2
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.