| shap_dependence | R Documentation |
SHAP value against the value of a single feature — the SHAP analog of a partial-dependence plot. Numeric features use a continuous x-axis; factor or character features fall back to their labels on a discrete axis.
shap_dependence(x, xvar = NULL, ...)
x |
A |
xvar |
The variable to plot. When |
... |
Unused. |
A ggplot object.
gg_shap plot.gg_shap
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.